@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/python3
 # -*- coding: utf-8 -*-
 """Process new requests to download per-package data"""
 # Copyright (C) 2012 Canonical Ltd
@@ -132,13 +132,13 @@ def trigger_update_notifier(failures, permanent=False):
 
     try:
         if permanent:
-            with open(NOTIFIER_PERMANENT_SOURCE_FILE, 'r') as f:
+            with open(NOTIFIER_PERMANENT_SOURCE_FILE, 'r', encoding='utf-8') as f:
                 input = f.read()
-            output_file = open(NOTIFIER_PERMANENT_FILE, 'w')
+            output_file = open(NOTIFIER_PERMANENT_FILE, 'w', encoding='utf-8')
         else:
-            with open(NOTIFIER_SOURCE_FILE, 'r') as f:
+            with open(NOTIFIER_SOURCE_FILE, 'r', encoding='utf-8') as f:
                 input = f.read()
-            output_file = open(NOTIFIER_FILE, 'w')
+            output_file = open(NOTIFIER_FILE, 'w', encoding='utf-8')
     except Exception:
         # Things failed and we can't even notify about it.  Break the
         # trigger so that there's some error propagation, even if not
